

set -ex



test -L $PREFIX/lib/libnvJitLink.so
test -f $PREFIX/lib/pkgconfig/nvjitlink*.pc
test -f $PREFIX/targets/sbsa-linux/include/nvJitLink.h
test -L $PREFIX/targets/sbsa-linux/lib/libnvJitLink.so
exit 0
